==> myfaces-core-assembly-2.0.25-src.zip: myfaces-core-module-2.0.25/impl/src/main/java/org/apache/myfaces/spi/impl/SpiUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.spi.impl;

import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.faces.context.ExternalContext;

import org.apache.myfaces.shared.util.ClassUtils;
import org.apache.myfaces.spi.ServiceProviderFinderFactory;

/**
 * Utils for SPI implementations.
 *
 * @since 2.0.3
 * @author Leonardo Uribe
 */
public final class SpiUtils
{
    
    public static Object build(ExternalContext ectx, Class spiClass, String defaultImpl)
    {
        List<String> classList = ServiceProviderFinderFactory.getServiceProviderFinder(ectx).getServiceProviderList(spiClass.getName());
        
        if (classList != null && !classList.isEmpty())
        {
            if (classList.size() > 1)
            {
                getLogger().log(Level.WARNING, "More than one SPI interface for "+spiClass.getName()+
                        " found :" + classList.toString() + ". Setting up the first one found.");
            }
            return ClassUtils.newInstance(classList.get(0));
        }
        return ClassUtils.newInstance(defaultImpl);
    }

    private static Logger getLogger()
    {
        return Logger.getLogger(SpiUtils.class.getName());
    }
}

==> myfaces-core-assembly-2.2.14-src.zip: myfaces-core-module-2.2.14/impl/src/main/java/org/apache/myfaces/spi/impl/SpiUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.spi.impl;

import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.faces.context.ExternalContext;

import org.apache.myfaces.shared.util.ClassUtils;
import org.apache.myfaces.spi.ServiceProviderFinderFactory;

/**
 * Utils for SPI implementations.
 *
 * @since 2.0.3
 * @author Leonardo Uribe
 */
public final class SpiUtils
{
    
    public static Object build(ExternalContext ectx, Class spiClass, String defaultImpl)
    {
        List<String> classList = ServiceProviderFinderFactory.getServiceProviderFinder(ectx).
                getServiceProviderList(spiClass.getName());
        
        if (classList != null && !classList.isEmpty())
        {
            if (classList.size() > 1)
            {
                getLogger().log(Level.WARNING, "More than one SPI interface for "+spiClass.getName()+
                        " found :" + classList.toString() + ". Setting up the first one found.");
            }
            return ClassUtils.newInstance(classList.get(0));
        }
        return ClassUtils.newInstance(defaultImpl);
    }

    private static Logger getLogger()
    {
        return Logger.getLogger(SpiUtils.class.getName());
    }
}
